/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

getDevice = function() {
    return (
        window.getComputedStyle(
            document.querySelector('html'), ':before'
        ).getPropertyValue('content')
        .replace(/["']/g, '') // Fix for: "'mobile'", ""mobile""...
    );
};

trimInput = function(value) {
	return value.replace(/^\s*|\s*$/g, '');
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */
var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		// activamos la pantalla principal (caracteristicas + ficha)
		activePrincipal: function(e){
			// reiniciamos eventos
			$('.area').off('click');

			// iterate through area objects to asign click event for modals
			_.each($('.area'), function(area, index) {
				 $(area).off('click').on('click', function(event) {
				 	event.preventDefault();

				 	if ( getDevice() !== 'mobile' && $(area).attr('data-tooltip') ) {
				 		tooltip = $('#'+$(area).data('tooltip'));
				 		if (tooltip.is(':visible')) {
				 			$('.area-tooltip').hide();
				 		}
				 		else{
				 			$('.area-tooltip').hide();
				 			tooltip.show();
				 			tooltip.off('click').on('click', function(event) {
					 			event.preventDefault();
					 			$(this).hide();
					 		});
				 		}
				 	}
				 	else {
				 		siteHandler.loadTemplate($(area).data('area'),'#nucleusModal .modal-body');

				 		var specialClass = $(area).attr('data-class');
				 		if ( specialClass )
				 			$('#nucleusModal .modal-dialog').addClass('special');
				 		else
				 			$('#nucleusModal .modal-dialog').removeClass('special');

					 	$('#nucleusModal').modal();
				 	}
				 });
			});

			$('.btn-0').off('click').on('click', function(){
				var $this = $(this),
				$helpText = $('.help-text');
				$helpIcon = $('.help-icon');

				if(getDevice() == "mobile") {
					// Muestra el contenedor
					$helpText.fadeIn(1000, function() {});
				}

				if(getDevice() != "mobile") {
					// Transción para moverlos
					$helpIcon.animate({ left: -210}, 1000, function() {});
					$helpText.animate({ left: 90}, 1000, function() {});
					// Muestra el contenedor
					$helpText.animate({ opacity: 1}, function() {});
				}

			});

			$('.btn-1').off('click').on('click', function(){
				var $this = $(this),
					$volcanContainer = $('.volcan-container'),
					$elements = $('.volcan-container h2, .volcan-container .head, .volcan-container .icon');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.find('.fa-stack-1x').toggleClass('fa-plus fa-minus');
					$this.addClass('playing');

					// Expande el contenedor
					$volcanContainer.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$volcanContainer.removeClass('active');

						$this.removeClass('playing');
						$this.find('.fa-stack-1x').toggleClass('fa-plus fa-minus');
					}, 600);
				}
			});

			$('.btn-2').off('click').on('click', function(){
				var $this = $(this),
					$volcanContainer = $('.volcan-container-2'),
					$elements = $('.volcan-container-2 h2, .volcan-container-2 .icon');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.find('.fa-stack-1x').toggleClass('fa-plus fa-minus');
					$this.addClass('playing');

					// Expande el contenedor
					$volcanContainer.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$volcanContainer.removeClass('active');

						$this.removeClass('playing');
						$this.find('.fa-stack-1x').toggleClass('fa-plus fa-minus');
					}, 600);
				}
			});

			$('.btn-3').off('click').on('click', function(){
				var $this = $(this);
				// Si no se está ejecutando
				if ( !$this.hasClass('playing') ) {
					// Se añade la clase playing para "bloquear" el evento.
					$this.addClass('playing');
					// Cambios el png por el gif
					if(getDevice() == "mobile") {
						$('#gif-mobile').attr('src','images/content/gif-mobile.gif');
					}
					if(getDevice() != "mobile") {
						$('#gif-tablet').attr('src','images/content/gif-tablet.gif');
					}

					// Cuando acabe la animación reseteamos todo y desbloqueamos el botón
					setTimeout(function(){

						if(getDevice() == "mobile") {
							$('#gif-mobile').attr('src','images/content/gif-mobile@2x.png');
						}
						if(getDevice() != "mobile") {
							$('#gif-tablet').attr('src','images/content/gif-tablet@2x.png');
						}
						$this.removeClass('playing');
						console.log('fin');
					}, 12000);
				}
			});

			$('.volcan-1').off('click').on('click', function(){
				var $this = $(this),
					$eruptionWrapper = $('.volcan-1 .eruption-wrapper'),
					$elements = $('.volcan-1 .head, .volcan-1 .volcan-wrapper, .volcan-1 .v-footer');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.addClass('playing');

					// Expande el contenedor
					$eruptionWrapper.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$eruptionWrapper.removeClass('active');

						$this.removeClass('playing');
					}, 600);
				}
			});

			$('.volcan-2').off('click').on('click', function(){
				var $this = $(this),
					$eruptionWrapper = $('.volcan-2 .eruption-wrapper'),
					$elements = $('.volcan-2 .head, .volcan-2 .volcan-wrapper, .volcan-2 .v-footer');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.addClass('playing');

					// Expande el contenedor
					$eruptionWrapper.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$eruptionWrapper.removeClass('active');

						$this.removeClass('playing');
					}, 600);
				}
			});

			$('.volcan-3').off('click').on('click', function(){
				var $this = $(this),
					$eruptionWrapper = $('.volcan-3 .eruption-wrapper'),
					$elements = $('.volcan-3 .head, .volcan-3 .volcan-wrapper, .volcan-3 .v-footer');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.addClass('playing');

					// Expande el contenedor
					$eruptionWrapper.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$eruptionWrapper.removeClass('active');

						$this.removeClass('playing');
					}, 600);
				}
			});

			$('.volcan-4').off('click').on('click', function(){
				var $this = $(this),
					$eruptionWrapper = $('.volcan-4 .eruption-wrapper'),
					$elements = $('.volcan-4 .head, .volcan-4 .volcan-wrapper, .volcan-4 .v-footer');

				// Se añade la clase playing para "bloquear" el evento.
				// Si la animación no está hecha...
				if ( !$this.hasClass('playing') && !$this.hasClass('done') ) {
					$this.addClass('playing');

					// Expande el contenedor
					$eruptionWrapper.addClass('active');

					// Ocultamos los elementos
					_.each($elements, function (element, index, list) {
						// Mostramos los elementos uno a uno
						$(element).delay(600*(index+1)).animate({ opacity: 1}, function() {});

						// Cuando termine marcamos la animación como hecha
						if (index == list.length -1) {
							setTimeout(function() {
								$this.removeClass('playing').addClass('done');
							}, 600*(index+2));
						}
					});
				}
				// Si la animación está hecha...
				else if ( !$this.hasClass('playing') && $this.hasClass('done') ) {
					// Ocultamos los elementos
					$elements.animate({ opacity: 0}, function() {});

					// Después de que se oculten los elementos contraemos el contenedor y desbloqueamos el botón
					setTimeout(function() {
						$this.removeClass('done');
						$eruptionWrapper.removeClass('active');

						$this.removeClass('playing');
					}, 600);
				}
			});

			// show/hide curtain
			$('#curtainIcon').off('click').on('click', function(event) {
				event.preventDefault();
				/* Act on the event */
				$('#curtainIcon .fa').toggleClass('fa-arrow-down fa-arrow-up');
				$('.curtain-wrapper').toggleClass('hide-curtain');
			});

			$('.cardinal').one('click', function(event) {
				/* Act on the event */
				var $parent = $(this).parent(),
					$cardinalInfo = $parent.find('.cardinal-info'),
					$cardinalText = $parent.find('.cardinal-text');

				console.log('okay jejejej');
				$(this).removeClass('shake');
				$cardinalInfo.addClass('animated fadeInRight').show();
				//mostrar texto aquí

				setTimeout(function(){
					$cardinalInfo.find('span').first().addClass('animated fadeInUp').css({'display': 'block'});
					$cardinalInfo.find('span').last().addClass('animated fadeInDown').css({'display': 'block'});
				}, 1000);

				setTimeout(function() {
					$cardinalText.addClass('animated fadeInRight').show();
				}, 1600);
			});
		},
		activeLegend: function() {
			$('#infoIcon').on('click', function(event) {
		        event.preventDefault();
		        event.stopPropagation();
		        /* Act on the event */
		        siteHandler.loadTemplate($(this).data('modal'),'#nucleusModalInfo .modal-body');
	            $('#nucleusModalInfo').modal();
	      	});
		},
		centerModals: function(){
			function modalCenter(){
				$('.modal').each(function(i){
					$clone = $(this).clone().css('display', 'block').appendTo('body');
					var top = Math.round(($clone.height() - $clone.find('.modal-content').height()) / 2);
					top = top > 0 ? top : 0;
					$clone.remove();
					$(this).find('.modal-content').css("margin-top", top);
				});
			}
			$('.modal').on('show.bs.modal', modalCenter);
			$(window).on('resize', modalCenter);
		},
		activeInfo: function() {
			$('.islands-data-icon').off('click').on('click', function() {
				$(this).parent().toggleClass('active');
			});
		},
		// activamos el mapa
		activeMap: function(e){
			L.mapbox.accessToken = 'pk.eyJ1Ijoiam9zZW5tYXIiLCJhIjoiRTBnY2plZyJ9.16b9pM_DfVdunAs6jZmE-A';

			if (getDevice() == 'mobile') {
				map = L.mapbox.map('map', 'josenmar.39411859').setView([28.358503954841247, -15.75439453125], 6);
				map.minZoom = 6;
				map.setZoom(6);
			}
			else {
				map = L.mapbox.map('map', 'josenmar.39411859').setView([28.013801376380712, -15.809326171875], 7);
				map.minZoom = 7;
				map.setZoom(7);
			}

			// load feature layer from geojson
			var myLayer = L.mapbox.featureLayer().loadURL('js/data/volcanes.json').addTo(map);

			// load scale indicator to map (left bottom)
			L.control.scale().addTo(map);

			// Set a custom icon on each marker based on feature properties.
			myLayer.on('layeradd', function(e) {
			    var marker = e.layer,
			        feature = marker.feature;

			    marker.setIcon(L.icon(feature.properties.icon));
			});
		},
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activePrincipal();
			siteHandler.setEvents.activeLegend();
			siteHandler.setEvents.centerModals();
			siteHandler.setEvents.activeInfo();
			siteHandler.setEvents.activeMap();
		});
	}
};

siteHandler.init();
